# $Id: compile.mk,v 1.10 2003/02/27 01:03:11 cxh Exp $
#
# Shared compilation rules for Diva
#
# Note that all "-w's" have been changed to "-r's" for TCSH support.
#

# This rules assumes that the following variables have been
# set, in addition to the variables that point to the Java
# installation:
#
# SUBPACKAGES:  The sub-packages that are to be compiled in the default
#            compilation. This should not include test/.
# SUBDIRS:      All sub-directories of this directory, for use by
#            the clean and install rules.
#
# The rules implemented by this file are:
#
# clean:    Remove all class files and junk from this package
#           including all subdirectories.
# classes:  Compile the classes in this dectory only.
# depend:   Rebuild java dependencies
# package:  Compile the classes in this directory and all
#           directories in SUBPACKAGES.
# all:      Compile the classes in this directory and all
#           directories in SUBDIRS.
# install:  In source directories, this is the same as make package.
# fast:     Compile all Java files regardless of dependencies. If you
#           are doing a make with a lot of out-of-date dependencies,
#           or a new build, this can be a lot faster than the regular build.
# local:    Compile all Java files regardless of dependencies in the
#           current directory and don't descend into subdirectories.
#
# The intent is that a user or casual developer can run "install"
# to generate class files, JAR files, API docs, and so on. A
# serious developer will need to run "all" to make everything,
# including the tests, but will not get the JAR files.


# Compile Java files
JCLASS = $(JSRCS:%.java=%.class)
.SUFFIXES: .class .java

# The default compile rule
.java.class:
	"$(JAVAC)" -classpath $(CLASSPATH) $(JAVAC_FLAGS) $<

# The default rule is "package."
default: package

# Compiling classes compiles just this directory
classes: $(JCLASS)

# Rebuild Java source dependencies
depend:
	@tclsh $(DIVA)/bin/divadmin generateDependencies

# Rebuild Java source dependencies "quickly:
fastdepend:
	@tclsh $(DIVA)/bin/divadmin generateDependencies -fast

# Compile subpackages
package: classes
	@if [ "x$(SUBPACKAGES)" != "x" ]; then \
		set $(SUBPACKAGES) ; \
		for x do \
		    if [ -r $$x ] ; then \
			( cd $$x ; \
			$(MAKE) $(MFLAGS) $(MAKEVARS) package ;\
			) \
		    fi ; \
		done ; \
	fi

# Rebuild ALL Java sources in current directory
local:
	@if [ "x$(JSRCS)" != "x" ]; then \
		"$(JAVAC)" -classpath $(CLASSPATH) $(JAVAC_FLAGS) $(JSRCS) ; \
	fi

# Rebuild ALL Java sources
fast:
	@if [ "x$(JSRCS)" != "x" ]; then \
		"$(JAVAC)" -classpath $(CLASSPATH) $(JAVAC_FLAGS) $(JSRCS) ; \
	fi
	@if [ "x$(SUBPACKAGES)" != "x" ]; then \
		set $(SUBPACKAGES) ; \
		for x do \
		    if [ -r $$x ] ; then \
			( cd $$x ; \
			$(MAKE) $(MFLAGS) $(MAKEVARS) fast ;\
			) \
		    fi ; \
		done ; \
	fi

# Compile this directories and all sub-directories.
# If SUBDIRS is not set, then add test to SUBPACKAGES and use that.
all: classes
	@if [ "x$(SUBDIRS)" != "x" ]; then \
		set $(SUBDIRS) ; \
		for x do \
		    if [ -r $$x ] ; then \
			( cd $$x ; \
			$(MAKE) $(MFLAGS) $(MAKEVARS) package ;\
			) \
		    fi ; \
		done ; \
	fi
	@if [ "x$(SUBDIRS)" = "x" ]; then \
		set $(SUBPACKAGES) test; \
		for x do \
		    if [ -r $$x ] ; then \
			( cd $$x ; \
			$(MAKE) $(MFLAGS) $(MAKEVARS) package ;\
			) \
		    fi ; \
		done ; \
	fi

# The install rule is the same as package
install: package

# Remove classes from this directory then subdirectories
clean:
	rm -f *.class core patch.exe.core *~ tmpfile
	@if [ "x$(SUBDIRS)" != "x" ]; then \
		set $(SUBDIRS) ; \
		for x do \
		    if [ -r $$x ] ; then \
			( cd $$x ; \
			$(MAKE) $(MFLAGS) $(MAKEVARS) clean ;\
			) \
		    fi ; \
		done ; \
	fi
	@if [ "x$(SUBDIRS)" = "x" ]; then \
		set $(SUBPACKAGES) test; \
		for x do \
		    if [ -r $$x ] ; then \
			( cd $$x ; \
			$(MAKE) $(MFLAGS) $(MAKEVARS) clean ;\
			) \
		    fi ; \
		done ; \
	fi

# Create an api directory in the current directory, for development purposes
api::
	$(DIVA)/bin/makeLocalApi \
		$(CLASSPATH) $(JAVAHOME) "$(JAVAC_FLAGS)" $(DIVA) $(JSRCS)

# Perform a CVS check on the local directory and subdirectories, highlighting
# makefiles and .java files that are not part of the repository.
checkcvs::
	$(DIVA)/bin/checkcvs

# echo the value of $MISCFILES.
# This rule is used to create the jar file
echo_MISC_FILES:
	@echo $(MISC_FILES)
